==> nextcloud-app-spreed-1%3A9.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/lb.js <==
OC.L10N.register(
    "spreed",
    {
    "Save changes" : "Ännerunge späicheren",
    "None" : "Keng",
    "User" : "User",
    "Disabled" : "Deaktivéiert",
    "Users" : "Benotzer",
    "Name" : "Numm",
    "Language" : "Sprooch",
    "Country" : "Land",
    "Pending" : "Ausstoend",
    "Error" : "Fehler",
    "Saved" : "Gespäichert",
    "Copy link" : "Link kopéieren",
    "Dismiss" : "Ofbriechen",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Gruppen",
    "Password protect" : "Passwuertgeschützt",
    "Back" : "Zeréck",
    "Close" : "Zoumaachen",
    "Reply" : "Äntwerten",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "guest" : "Gaascht",
    "Add users or groups" : "Add users or groups",
    "Settings" : "Astellungen",
    "Edit" : "Änneren",
    "Share link" : "Link deelen",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
    "Password" : "Passwuert",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Copied!" : "Kopéiert!",
    "Not supported!" : "Nët ennerstëtzt!",
    "Press ⌘-C to copy." : "Dréck ⌘-C fir ze kopéieren.",
    "Press Ctrl-C to copy." : "Dréck CTRL-C fir ze kopéieren.",
    "Cancel" : "Ofbriechen",
    "Change password" : "Passwuert änneren",
    "Rename" : "Ëmbenennen",
    "Send" : "Schécken",
    "Share" : "Deelen",
    "Error while sharing" : "Feeler beim Deelen",
    "Favorited" : "Favoriséiert",
    "Contacts" : "Kontakter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A10.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/lb.js <==
OC.L10N.register(
    "spreed",
    {
    "Save changes" : "Ännerunge späicheren",
    "None" : "Keng",
    "User" : "User",
    "Disabled" : "Deaktivéiert",
    "Users" : "Benotzer",
    "Name" : "Numm",
    "Language" : "Sprooch",
    "Country" : "Land",
    "Pending" : "Ausstoend",
    "Error" : "Fehler",
    "Saved" : "Gespäichert",
    "Copy link" : "Link kopéieren",
    "Dismiss" : "Ofbriechen",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Gruppen",
    "Settings" : "Astellungen",
    "Password protect" : "Passwuertgeschützt",
    "Back" : "Zeréck",
    "Close" : "Zoumaachen",
    "Reply" : "Äntwerten",
    "Remove" : "Läschen",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "Enabled" : "Aktivéiert",
    "Save" : "Späicheren",
    "Password" : "Passwuert",
    "Login" : "Login",
    "Nickname" : "Spëtznumm",
    "Client ID" : "Client ID",
    "guest" : "Gaascht",
    "Add users or groups" : "Add users or groups",
    "Edit" : "Änneren",
    "Search" : "Search",
    "Share link" : "Link deelen",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Send" : "Schécken",
    "Default" : "Standard",
    "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Contacts" : "Kontakter",
    "Cancel" : "Ofbriechen"
},
"nplurals=2; plural=(n != 1);");
